Represents an HCL block label.
In HCL syntax this can be represented either as a quoted string literal…
block_identifier "block_label1" {
body
}…or as a bare identifier:
block_identifier block_label1 {
body
}Variants
Identifier(String)
A bare HCL block label.
StringLit(String)
A quoted string literal.
Implementations
sourceimpl BlockLabel
impl BlockLabel
sourcepub fn identifier<I>(identifier: I) -> Self where
I: Into<String>,
pub fn identifier<I>(identifier: I) -> Self where
I: Into<String>,
Creates a new bare BlockLabel identifier.
sourcepub fn string_lit<S>(string: S) -> Self where
S: Into<String>,
pub fn string_lit<S>(string: S) -> Self where
S: Into<String>,
Creates a new quoted string BlockLabel.
sourcepub fn into_inner(self) -> String
pub fn into_inner(self) -> String
Consumes self and returns the String wrapped by the BlockLabel.
Beware that after calling .into_inner() it is not possible anymore to tell whether the
String resembles a quoted string or bare identifer.